@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,11 +19,11 @@
 #      along with this program.
 #
 #  File: compute.tcl
-#  Last change:  16 December 2009
+#  Last change:  19 July 2011
 #
 # Includes contributions by
-#  - Matt Martin (matt.martin@ieee.org) marked "MGM contribution"
-#  - Valere Robin (valere.robin@wanadoo.fr) marked "VR contribution"
+#  - Matt Martin (matt.martin _AT_ ieee.org) marked "MGM contribution"
+#  - Valere Robin (valere.robin _AT_ wanadoo.fr) marked "VR contribution"
 #
 
 ## Some formulae kindly supplied by
@@ -1121,7 +1123,7 @@ proc LocalTimeAndUTC {y m d h mn s origin} {
     # return list with same elements as in the args
     global TimeOffset DAYSOF
 
-    if { $origin == "UTC" } {
+    if { $origin != "UTC" } {
 	incr h $TimeOffset
     } else { set h [expr $h-$TimeOffset] }
     if { $h < 0 } {
