@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,7 +19,7 @@
 #      along with this program.
 #
 #  File: files.tcl
-#  Last change:  23 August 2009
+#  Last change:  4 August 2011
 #
 # See also files_foreign.tcl
 #  and metadata.tcl for properties of known file formats
@@ -26,6 +28,7 @@
 #   - Brian Baulch (baulchb _AT_ onthenet.com.au) marked "BSB contribution"
 #   - Matt Martin (matt.martin _AT_ ieee.org) marked "MGM contribution"
 #   - Valere Robin (valere.robin _AT_ wanadoo.fr) marked "VR contribution"
+#   - Rudolf Martin (rudolf.martin _AT_ gmx.de) marked "RM contribution"
 #
 
 array set FCOMMAND {
@@ -511,8 +514,13 @@ proc SaveTRComp {file w} {
     foreach k "frsp.avg frsp.max frsp.min" {
 	puts $file [$w.$k cget -text]
     }
+    # RM contribution
+    foreach k "frrest.avg frrest.trt" {
+	puts $file [$w.$k cget -text]
+    }
+    #===
     if { [winfo exists $w.frmxnalt] } {
-	foreach k "frmxnalt.mx frmxnalt.mn frcad.cumul frcad.cumuld" {
+	foreach k "frmxnalt.mx frmxnalt.mn frcad.cumula frcad.cumuld" {
 	    puts $file [$w.$k cget -text]
 	}
     }
@@ -692,6 +700,7 @@ proc SaveFileTo {f how what args} {
     # save information to file $f in GPSMan format
     # if $f=="" ask user to select output file
     # if $f!="stdout" file will be closed at the end
+    # only when $how=="comp" file can be appended to if it exists
     # see proc SaveFile for the description of the arguments
     global SFilePFrmt SFileDatum SFileHeader TXT TYPES SUPPORTLAPS File
 
@@ -700,6 +709,7 @@ proc SaveFileTo {f how what args} {
     if { $how == "state" } {
 	set slow 0
     } else { set slow 1 }
+    set mode w
     switch $how {
 	all -  state {
 	    set lp [AllIndicesForType $what $stypes]
@@ -708,11 +718,11 @@ proc SaveFileTo {f how what args} {
 	    if { [set ixs [ChooseItems $what]] == "" } { return }
 	    set lp [list [list $what $ixs]]
 	}
-	comp { }
+	comp { set mode wapp }
 	mapinfo -  mapback { set slow 0 }
     }
     set oldf $f
-    if { $f != "" || [set f [GMOpenFile $TXT(saveto) $what w]] != ".." } {
+    if { $f != "" || [set f [GMOpenFile $TXT(saveto) $what $mode]] != ".." } {
 	if { $slow } {
 	    set sid [SlowOpWindow $TXT(save)]
 	} else { SetCursor . watch }
@@ -942,17 +952,17 @@ proc SaveCanvas {cv bounds fmt dest} {
     # items with tag "temp" can be created in and deleted from $cv
     # if $cv==$Map inclusion of map scale is an option
     # when printing, a temporary file named "print.tmp" is created in the
-    #  user GPSMan-data directory
+    #  user GPSMan temporary files directory
     global PRINTCMD PAPERSIZE PAGEWIDTH PAGEHEIGHT GFMode GFRot \
-	GFPaper GFLegend GFVisible GFScale GFPrintOption MESS TXT MAPCOLOUR \
-	Map MpW MAPSCLENGTH USERDIR MapFont FixedFont SHOWFILEITEMS
+	GFPaper GFLegend GFOnlyVisible GFScale GFPrintOption MESS TXT \
+	MAPCOLOUR Map MpW MAPSCLENGTH USERTMPDIR MapFont FixedFont
 
     set leg "=$TXT(legend)"
     set cms [list $TXT(colour) $TXT(grey) $TXT(mono)]
-    set GFVisible $SHOWFILEITEMS ; set GFMode $TXT(colour)
+    set GFOnlyVisible 0 ; set GFMode $TXT(colour)
     switch $fmt {
 	PS {
-	    set vs "GFLegend GFMode GFRot GFPaper"
+	    set vs {GFLegend GFMode GFRot GFPaper}
 	    set pps [array names PAGEWIDTH]
 	    if { [set i [lsearch -exact $pps $PAPERSIZE]] != 0 } {
 		set pps [linsert [lreplace $pps $i $i] 0 $PAPERSIZE]
@@ -960,16 +970,16 @@ proc SaveCanvas {cv bounds fmt dest} {
 	    set ds [list $leg $cms [list $TXT(portr) $TXT(landsc)] $pps]
 	}
 	jpeg {
-	    set vs "GFLegend GFMode"
+	    set vs {GFLegend GFMode}
 	    set ds [list $leg [lreplace $cms 2 2]]
 	}
 	default {
-	    set vs "GFLegend"
+	    set vs {GFLegend}
 	    set ds [list $leg]
 	}
     }
-    if { $bounds != "" && $fmt == "PS" } {
-	set vs [linsert $vs 1 GFVisible]
+    if { $bounds != {} && $fmt == "PS" } {
+	set vs [linsert $vs 1 GFOnlyVisible]
 	set ds [linsert $ds 1 "@$TXT(psvisible)"]
     }
     if { $cv == $Map } {
@@ -993,21 +1003,21 @@ proc SaveCanvas {cv bounds fmt dest} {
 	    lappend vs GFPrintOption
 	    lappend ds "=$TXT(printopt)"
 	    if { ! [GMChooseParams $TXT(print) $vs $ds] } { return }
-	    set fn [file join $USERDIR print.tmp]
+	    set fn [file join $USERTMPDIR print.tmp]
 	}
     }
     if { $fn != ".." } {
 	SetCursor . watch
-	foreach m $cms tm "color gray mono" {
+	foreach m $cms tm {color gray mono} {
 	    if { $GFMode == $m } {
 		set GFMode $tm
 		break
 	    }
 	}
-	if { $GFVisible } {
+	if { $GFOnlyVisible && $mbs != {} } {
 	    set mbs $bounds
 	} else { set mbs [$cv bbox all] }
-	foreach "x0 y0 xf yf" $mbs { break }
+	foreach {x0 y0 xf yf} $mbs { break }
 	set sm [expr ($xf+$x0)/2.0]
 	if { $GFScale } {
 	    # only applies when $cv == $Map
@@ -1026,7 +1036,7 @@ proc SaveCanvas {cv bounds fmt dest} {
 	    if { [set xsf [expr $xs0+$m]] > $xf } {
 		set xf $xsf
 	    }
-	    if { $GFVisible } {
+	    if { $GFOnlyVisible } {
 		set ys [expr $yf-100]
 	    } else { set ys [expr $yf+60] ; set yf [expr $ys+10] }
 	    set yd [expr $ys-7.5] ; set ylf [expr $ys+7.5]
@@ -1040,7 +1050,7 @@ proc SaveCanvas {cv bounds fmt dest} {
 		    -fill $MAPCOLOUR(mapsel) -text "$sc $su" -tags temp
 	}
 	if { $GFLegend != "" } {
-	    if { $GFVisible } {
+	    if { $GFOnlyVisible } {
 		set yt [expr $yf-60]
 	    } else {
 		set yt [expr $yf+20] ; set yf [expr $yt+5]
@@ -1063,7 +1073,7 @@ proc SaveCanvas {cv bounds fmt dest} {
 			set sca $PAGEHEIGHT($GFPaper)
 		    } else { set sca $PAGEWIDTH($GFPaper) }
 		}
-		if { $GFVisible } {
+		if { $GFOnlyVisible } {
 		    $cv postscript -file $fn -colormode $GFMode $sc $sca \
 			    -rotate $rot
 		} else {
@@ -1818,7 +1828,6 @@ proc LoadWPs {file outRT importing how} {
 		    }
 		    lappend LFileRTStages($file) \
 			    [list $count $LFileOther($file)]
-		    incr count -1
 		}
 		nb {
 		    if { $how != "void" } {
@@ -1832,9 +1841,6 @@ proc LoadWPs {file outRT importing how} {
 		    GMMessage "$MESS(badcommdWP) $LFileLNo($file)"
 		    return ""
 		}
-		default {
-		    if { $count > 0 } { incr count -1 }
-		}
 	    }
 	    continue
 	}
