@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,7 +19,7 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  18 December 2009
+#  Last change:  15 September 2011
 #
 # Includes contributions by
 #  - Brian Baulch (baulchb _AT_ onthenet.com.au)
@@ -25,6 +27,8 @@
 #  - Jean H Theoret (ve2za _AT_ rac.ca)
 #  - Valere Robin (valere.robin _AT_ wanadoo.fr)
 #  - David Gardner (djgardner _AT_ users.sourceforge.net)
+#  - Rudolf Martin (rudolf.martin _AT_ gmx.de)
+#
 
 # only 3 chars long names; check also ALLMONTH in file i18n-utf8.tcl
 set MONTHNAMES "Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec"
@@ -310,8 +314,21 @@ array set MESS {
     badpluginparam "Bad plug-in parameters: list of NAME EXPR, NAME starts with _"
     badpluginparamexec "When running plug-in %s, bad parameter: %s"
     pluginfailed "Plug-in %s failed with message: %s"
-    canwrtaux "Cannot write auxiliary file"
     loginto "Login %s"
+    cantwrtdir "Cannot write on %s; please change its permissions"
+    cantcleandir "Could not clear directory %s"
+    defTERMCMD "The option for the command that opens a terminal window must be defined first"
+    gpOutfile "Output is in file \"%s\" in your working directory."
+    gpQuitgnuplot "Press Enter in xterm window to quit gnuplot."
+    gpModgnuplot "Modify the viewing in the Gnuplot-window\
+                  by dragging the mouse (left and middle button).\n\
+                  After closing the gnuplot-window you will find\
+                  the output in file \"%s\" in your working directory."
+    htResult1 "Track=\"%s\""
+    htResult2 "Total distance=%s  Total ascent=%s  Total descent=%s"
+    htResult3 "Used total time=%s  Resting Time=%s(%s)  Time in motion=%s"
+    htResult4 "%s  Cap.plain=%s  Cap.asc=%s  Cap.desc=%s  Est. hiking time=%s"
+    srResult1 "Rest periods (>5min) of track \"%s\""
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -413,6 +430,8 @@ array set TXT {
     tottime   "Total time"
     totdstng   "Total distance, no gaps"
     tottimeng  "Total time, no gaps"
+    totresttime  "Total time of resting (>5min)"
+    avgspmot  "Average speed in motion"
     track   Track
     chophd   "Chop head"
     choptl   "Chop tail"
@@ -960,6 +979,10 @@ array set TXT {
     PRJIcG "Iceland Grid"
     PRJRDG "The Netherlands Grid"
     PRJSchreiber Schreiber
+    PRJSphMerc "Spherical Mercator"
+    PRJEqCyl "Equidistant Cylindrical"
+    PRJEPSG:3857 "EPSG:3857"
+    PRJEPSG:32663 "EPSG:32663"
     dontaskagain "Stop asking"
     rename "Use new name"
     oname "Original name"
@@ -1315,8 +1338,8 @@ array set TXT {
     rmsxydev "rms(x,y-deviations)"
     resstderr "residual std error"
     chgdev "Change device"
-    alt_cumul "Cummulative ascent"
-    alt_cumuld "Cummulative descent"
+    alt_cumula "Total ascent"
+    alt_cumuld "Total descent"
     maxalt "Maximum altitude"
     minalt "Minimum altitude"
     optSHOWFILEITEMS "By default display on map items read in"
@@ -1391,6 +1414,57 @@ array set TXT {
     wptotwitternb "Send WP position, datum, altitude, name and comment to Twitter with tags #GPSMan #waypoint"
     exportTFW "Export TFW file"
     nametfwfile "TFW file"
+    gpTRtoGnuplot2d "Side-view (Gnuplot)"
+    gpTRtoGnuplot2d_nb "Send Track data to external program GNUPLOT and display altitude chart"
+    gpTRtoGnuplot3d "Perspective (Gnuplot)"
+    gpTRtoGnuplot3d_nb "Send Track data to external program GNUPLOT and display 3D-chart"
+    gpParam2d "Parameters for Gnuplot 2D-Chart"
+    gpParam3d "Parameters for Gnuplot 3D-Chart"
+    gpFilename "Filename"
+    gpCanwidth   "Canvas width"
+    gpCanheight  "Canvas height"
+    gpSTotals  "Show totals"
+    gpLeft  "Left side"
+    gpRight "Right side"
+    gpNone  "None"
+    gpSRests "Show rests"
+    gpRest  "Rest"
+    gpSymText "Symbol+Text"
+    gpSymTime "Symbol+Time"
+    gpText  "Text"
+    gpSHours "Show hours"
+    gpTimetop "Time at top"
+    gpTimebot "Time at bottom"
+    gpSSpeed "Show speed"
+    gpHike  "Hike"
+    gpBike  "Bike"
+    gpDrive "Drive"
+    gpGlide "Glide"
+    gpLimitDist "Max. Distance WP to Track (km)"
+    gpLimitStat "Min. Lenght on Track for same WP (km)"
+    gpDirection "Direction"
+    gpForward "Forward"
+    gpBackward "Backward"
+    gp2D_hlp "If there is a groupname identical to the track name,\n\
+              the waypoints of this group will be displayed,\n\
+              in consideration of the given distances.\n\
+              When no matching group name exists,\
+              you can choose from a list or cancel."
+    gpGenerated "Generated with gnuplot by GPSMan"
+    gpModify "Modify viewing with mouse. Quit to save picture."
+    htCalcHikeTime "Calculate Hiking Time"
+    htCalcHikeTime_nb "Calculate Hiking Time with formula from DAV"
+    htHeader "Estimated hiking time (without resting) for tracks\
+               using the formula from \"Deutscher Alpenverein\" with different parameters"
+    htFooter1 "Capacity refers to one hour."
+    htFooter2 "Suggested resting time is 20min after two hours (15%)."
+    srShowRest_nb "Show rest periods > 5min."
+    srTRTime   "Track time"
+    srTotals   "Totals"
+    optALTHRESHOLD "Altitude threshold"
+    optDISPLAYCMD "Command to display image file"
+    optTERMCMD "Command to open terminal window"
+    optMANHTTPADDR "User manual HTTP address"
 }
 
     # the following definitions must be coherent with $TXT
@@ -1411,3 +1485,13 @@ array set INVTXT {
     ft   FT
 }
 
+# changes by Miguel Filgueiras to RM contribution
+set TXT(srChainage) $TXT(totdst)
+set TXT(srShowRest) $TXT(gpSRests)
+set TXT(gpSym) $TXT(symbol)
+set TXT(srRest) $TXT(gpRest)
+
+
+
+
+
