@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,9 +19,9 @@
 #      along with this program.
 #
 #  File: langes.tcl
-#  Last change:  16 March 2009
+#  Last change:  15 September 2011
 #
-# Spanish language file by Alberto Morales (amd77@gulic.org)
+# Spanish language file by Alberto Morales (amd77 _AT_ gulic.org)
 #  last input from him: 21 April 2007
 #
 
@@ -1272,4 +1274,9 @@ array set INVTXT {
     GR   GR
 }
 
+# changes by Miguel Filgueiras to RM contribution
+set TXT(srChainage) $TXT(totdst)
+set TXT(srShowRest) $TXT(gpSRests)
+set TXT(gpSym) $TXT(symbol)
+set TXT(srRest) $TXT(gpRest)
 
