@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,7 +19,7 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  27 December 2009
+#  Last change:  16 September 2011
 #
 # French language file by Valre Robin (valere.robin _AT_ wanadoo.fr)
 #  Last change by him:  11 November 2001
@@ -1259,7 +1261,7 @@ array set TXT {
     alm_health "sant"
     lstsqs "Moindres carrs"
     lstsqsfile "Fichier des moindres carrs"
-    alt_cumul "Dnivell cumul positif"
+    alt_cumula "Dnivell cumul positif"
     optSHOWFILEITEMS "Affichage par dfaut des donnes lues"
     totdstng   "Distance totale, sans les sauts"
     tottimeng  "Temps total, sans les sauts"
@@ -1365,3 +1367,9 @@ array set INVTXT {
     ETP LAP
     GR   GR
 }
+
+# changes by Miguel Filgueiras to RM contribution
+set TXT(srChainage) $TXT(totdst)
+set TXT(srShowRest) $TXT(gpSRests)
+set TXT(gpSym) $TXT(symbol)
+set TXT(srRest) $TXT(gpRest)
