@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,8 +19,8 @@
 #      along with this program.
 #
 #  File: langit.tcl
-#  Last change:  22 December 2009
-#  Italian language file by Alessandro Palmas (alpalmas@tin.it)
+#  Last change:  16 September 2011
+#  Italian language file by Alessandro Palmas (alpalmas _AT_ tin.it)
 #  last input from him inserted:  22 December 2009
 #
 
@@ -1216,7 +1218,7 @@ array set TXT {
     chgdev "Cambia dispositivo"
     maxalt "Altitudine massima"
     minalt "Altitudine minima"
-    alt_cumul "Altezza cumulativa di salita"
+    alt_cumula "Altezza cumulativa di salita"
     alt_cumuld "Discesa cumulativa"
     optSHOWFILEITEMS "Mostra di default sulla mappa gli oggetti leti da file"
     vertgridlines "Linee Vert Griglia"
@@ -1307,3 +1309,8 @@ array set INVTXT {
     GR   GR
 }
 
+# changes by Miguel Filgueiras to RM contribution
+set TXT(srChainage) $TXT(totdst)
+set TXT(srShowRest) $TXT(gpSRests)
+set TXT(gpSym) $TXT(symbol)
+set TXT(srRest) $TXT(gpRest)
