@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,8 +19,8 @@
 #      along with this program.
 #
 #  File: langnl.tcl
-#  Last change:  27 December 2009
-#  Dutch language file by Rob Buitenhuis (rob@buitenhs.demon.nl)
+#  Last change:  16 September 2011
+#  Dutch language file by Rob Buitenhuis (rob _AT_ buitenhs.demon.nl)
 #  last input from him inserted: 27 December 2009
 #
 # 
@@ -1250,7 +1252,7 @@ array set TXT {
     chgdev "Verander device"
     maxalt "Maximum hoogte"
     minalt "Minimum hoogte"
-    alt_cumul "Cummulatief klimhoogte"
+    alt_cumula "Cummulatief klimhoogte"
     alt_cumuld "Cummulatief afdaling"
     optSHOWFILEITEMS "Toon standaard de ingelezen zaken"
     vertgridlines "Vert Grid Lijnen"
@@ -1339,3 +1341,9 @@ array set INVTXT {
     RD   LAP
     GR   GR
 }
+
+# changes by Miguel Filgueiras to RM contribution
+set TXT(srChainage) $TXT(totdst)
+set TXT(srShowRest) $TXT(gpSRests)
+set TXT(gpSym) $TXT(symbol)
+set TXT(srRest) $TXT(gpRest)
