@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,7 +19,7 @@
 #      along with this program.
 #
 #  File: langport.tcl
-#  Last change:  18 December 2009
+#  Last change:  16 September 2011
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -306,8 +308,8 @@ array set MESS {
     badpluginparam "Erro nos parmetros de extenso: lista de NOME EXPR, NOME iniciado por _"
     badpluginparamexec "Ao correr extenso %s, parmetro errado: %s"
     pluginfailed "Extenso %s falhou com mensagem: %s"
-    canwrtaux "No posso escrever um ficheiro auxiliary"
     loginto "Acesso a %s"
+    cantwrtdir "No posso escrever em %s; p.f. altere as permisses"
 }
 
 set TXT(RTcompflds) "# PT {$DTUNIT} grau {$ALUNIT} etapa etiq"
@@ -927,6 +929,8 @@ array set TXT {
     PRJLV03 "Grelha Suia LV03"
     PRJIcG "Grelha Islandesa"
     PRJRDG "Grelha Holandesa"
+    PRJSphMerc "Mercator Esfrica"
+    PRJEqCyl "Cilndrica Equidistante"
     dontaskagain "Deixar de confirmar"
     rename "Usar nome diferente"
     oname "Nome original"
@@ -1262,7 +1266,7 @@ array set TXT {
     rmsxydev "media_quadr(x,y-desvios)"
     resstderr "erro std residual"
     chgdev "Alterar porta"
-    alt_cumul "Altitude subida acumulada"
+    alt_cumula "Altitude subida acumulada"
     alt_cumuld "Altitude descida acumulada"
     maxalt "Altitude mxima"
     minalt "Altitude mnima"
@@ -1337,6 +1341,58 @@ array set TXT {
     wptotwitternb "Enviar a posio, datum, altitude, nome e comentrio de PT para Twitter com marcas #GPSMan #waypoint"
     exportTFW "Exportar ficheiro TFW"
     nametfwfile "Ficheiro TFW"
+    gpTRtoGnuplot2d "Vista lateral (Gnuplot)"
+    gpTRtoGnuplot2d_nb "Mostrar grfico de altitude com os dados do Trajecto usando o programa externo GNUPLOT"
+    gpTRtoGnuplot3d "Perspectiva (Gnuplot)"
+    gpTRtoGnuplot3d_nb "Mostrar grfico 3D de altitude com os dados do Trajecto usando o programa externo GNUPLOT"
+    gpParam2d "Parmetros para grfico 2D por Gnuplot"
+    gpParam3d "PParmetros para grfico 3D por Gnuplot"
+    gpFilename "Ficheiro"
+    gpCanwidth   "Comprimento da tela"
+    gpCanheight  "Altura da tela"
+    gpSTotals  "Mostrar totais"
+    gpLeft  " esquerda"
+    gpRight " direita"
+    gpNone  "Nenhum"
+    gpSRests "Mostrar pausas"
+    gpRest  "Pausa"
+    gpSymText "Smbolo+Texto"
+    gpSymTime "Smbolo+Tempo"
+    gpText  "Texto"
+    gpSym   "Smbolo"
+    gpSHours "Mostrar horas"
+    gpTimetop "Tempo em cima"
+    gpTimebot "Tempo em baixo"
+    gpSSpeed "Mostrar velocidade"
+    gpHike  "A p"
+    gpBike  "Bicicleta"
+    gpDrive "Carro"
+    gpGlide "Voo"
+    gpLimitDist "Distncia mxima PT a TR (km)"
+    gpLimitStat "Distncia mnima no TR mesmo PT (km)"
+    gpDirection "Direco"
+    gpForward "Frente"
+    gpBackward "Trs"
+    gp2D_hlp "Havendo um grupo com o mesmo nome do TR,\n\
+              os PTs do grupo sero mostrados,\n\
+              dependendo das distncias dadas.\n\
+              Se no houver um grupo assim,\n\
+              escolher os PTs ou cancelar."
+    gpGenerated "Gerado com Gnuplot por GPSMan"
+    gpModify "Alterar a vista com o rato. Sair para salvar a imagem."
+    htCalcHikeTime "Calcular tempo de percurso"
+    htCalcHikeTime_nb "Calcular tempo de percurso pela frmula da DAV"
+    htHeader "Tempo estimado de percurso (sem pausas) pela frmula da \
+              \"Deutscher Alpenverein\" com parmetros dados"
+    htFooter1 "Capacidade em uma hora."
+    htFooter2 "Tempo sugerido de pausa  de 20min depois de 2 horas (15%)."
+    srShowRest_nb "Mostrar pausas > 5min."
+    srTRTime   "Tempo de trajecto"
+    srTotals   "Totais"
+    optALTHRESHOLD "Limiar de altitude"
+    optDISPLAYCMD "Comando para mostrar ficheiro de imagem"
+    optTERMCMD "Comando para abrir janela de terminal"
+    optMANHTTPADDR "Endereo HTTP do manual"
 }
 
     # the following definitions must be coherent with $TXT
@@ -1353,3 +1409,9 @@ array set INVTXT {
     GR   GR
     p   FT
 }
+
+# changes by Miguel Filgueiras to RM contribution
+set TXT(srChainage) $TXT(totdst)
+set TXT(srShowRest) $TXT(gpSRests)
+set TXT(gpSym) $TXT(symbol)
+set TXT(srRest) $TXT(gpRest)
