@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 1998-2009 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 1998-2010 Miguel Filgueiras migf _AT_ portugalmail.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,7 +19,7 @@
 #      along with this program.
 #
 #  File: options.tcl
-#  Last change:  18 December 2009
+#  Last change:  15 September 2011
 #
 
 # when inserting new data here, define TXT(opt*)
@@ -116,7 +118,8 @@ set OPTTYPE(KEEPHIDDEN) oneof
 set OPTVALS(KEEPHIDDEN) {never ask always}
 
 set OPTTYPE(_Formats) group
-set OPTGRPL(_Formats) {Datum TimeOffset DISTUNIT ALTUNIT PositionFormat
+set OPTGRPL(_Formats) {Datum TimeOffset DISTUNIT ALTUNIT ALTHRESHOLD
+                       PositionFormat
                        DateFormat DEFMAPPROJ DEFMAPPFRMT DEFMAPPFDATUM
                        ACCFORMULAE ASKPROJPARAMS}
 
@@ -131,6 +134,8 @@ set OPTVALS(DISTUNIT) {KM NAUTMILE STATMILE}
 set OPTTYPE(ALTUNIT) oneof
 set OPTVALS(ALTUNIT) {M FT}
 
+set OPTTYPE(ALTHRESHOLD) nat
+
 set OPTTYPE(PositionFormat) fixedmenu
 set OPTMENUCONTS(PositionFormat) $PFORMATS
 
@@ -217,7 +222,9 @@ if { $UNIX } {
     set OPTTYPE(DEFSPORT) any
 } else { set OPTGRPL(_Files) "" }
 lappend OPTGRPL(_Files) SAVESTATE DELSTATE _sep PERMS PRINTCMD PAPERSIZE \
-	_sep MapGuideVersion
+        DISPLAYCMD TERMCMD _sep MapGuideVersion
+
+## MANHTTPADDR not yet in this group
 
 set OPTTYPE(SAVESTATE) oneof
 set OPTVALS(SAVESTATE) {never ask always}
@@ -227,6 +234,9 @@ set OPTTYPE(PERMS) perms
 set OPTTYPE(PRINTCMD) any_empty
 set OPTTYPE(PAPERSIZE) fixedmenu
 set OPTMENUCONTS(PAPERSIZE) [array names PAGEWIDTH]
+set OPTTYPE(DISPLAYCMD) any_empty
+set OPTTYPE(TERMCMD) any_empty
+set OPTTYPE(MANHTTPADDR) any_empty
 set OPTTYPE(MapGuideVersion) fixedmenu
 set OPTMENUCONTS(MapGuideVersion) {2002 03/04}
 
@@ -352,7 +362,7 @@ proc SetOptions {} {
 		}
 		if { $ok } {
 		    if { [catch {set f [open $USEROPTIONS w]}] } {
-			GMMessage $MESS(cantwrtopt)
+			GMMessage $MESS(cantwrtopt) wait
 			set res 0
 			break
 		    }
