@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,15 +19,15 @@
 #      along with this program.
 #
 #  File: projections.tcl
-#  Last change:  12 February 2009
+#  Last change:  5 August 2011
 #
 
 # Includes contributions by
 #  - Sandor Laky (laky.sandor_AT_freemail.hu) marked "SL contribution"
 
 ## some information and algorithms used here adopted from
-#  - libproj, PROJ4.4 and PROJ4.3.3 - cartographic projection software
-#      by Gerald I. Evenden (gie@kai.er.usgs.gov)
+#  - libproj 4.6.1, PROJ4.4 and PROJ4.3.3 - cartographic projection software
+#      by Gerald I. Evenden (gie_at_kai.er.usgs.gov)
 #  - Guidance Note Number 7, European Petroleum Survey Group
 #      Revised November 1999
 #  - Formulas and constants for the calculation of the Swiss conformal
@@ -36,7 +38,7 @@
 #    Reference System 1989 (containing formulas and constants for the
 #    Schreiber projection and the RD grid, used in The Netherlands;
 #    partial English translation kindly provided by Rob Buitenhuis,
-#    rob@buitenhs.demon.nl), http://www.rdnap.nl
+#    rob_at_buitenhs.demon.nl), http://www.rdnap.nl
 #  - "Le carte topografiche CTR ed il loro uso GPS"
 #    (http://www.gpscomefare.com/guide/tutorialgps/mapdatum.htm)
 #    May 2003 (information kindly sent by Alessandro Palmas)
@@ -47,14 +49,14 @@
 
 ##
 ## some algorithms and formulae adopted from:
-#     - GKK grid conversion by Andreas Lange (Andreas.C.Lange@GMX.de)
+#     - GKK grid conversion by Andreas Lange (Andreas.C.Lange_at_GMX.de)
 #       in GPStrans 0.36
 #     - Swedish grid conversion by Anders Lennartsson
-#       (anders.lennartsson@sto.foa.se) in GPStrans 0.36
+#       (anders.lennartsson_at_sto.foa.se) in GPStrans 0.36
 ##
 ## information kindly provided by
-#     - Dan Jacobson (jidanni@yahoo.com.tw) on the Taiwan Grid projection
-#     - Alessandro Palmas (alpalmas@tin.it) on the French and Austrian grids
+#     - Dan Jacobson (jidanni_at_yahoo.com.tw) on the Taiwan Grid projection
+#     - Alessandro Palmas (alpalmas_at_tin.it) on the French and Austrian grids
 ##
 
 ## "projection" here means the conversion from geodetic position to
@@ -76,8 +78,9 @@
 ##
 
 set MAPKNOWNPROJS {UTM TM BMN BNG BWI CMP CTR GKK ITM KKJY KKJP SEG TWG
-                   LCC1 LCC2 IcG Merc1 Merc2 CS APOLY Stereogr Schreiber RDG
-                   SOM LV03 Lamb93 LambNTFe LambNTF AEA LEAC TAlbers EOV}
+                   LCC1 LCC2 IcG Merc1 Merc2 SphMerc EPSG:3857 CS APOLY Stereogr
+		   Schreiber RDG SOM LV03 Lamb93 LambNTFe LambNTF EqCyl
+		   EPSG:32663 AEA LEAC TAlbers EOV}
 
      # indices of parameters array used for each main projection
      #  index "datum" is also used, but is dealt with in a different way
@@ -98,12 +101,14 @@ array set MAPPROJDATA {
     LEAC  {lat1 polasp lat0 long0 m_e m_a m_0 m_1 m_2 m_3 m_4 m_5}
     Merc1 {long0 k0 m_e m_a m_1 m_2 m_3 m_4}
     Merc2 {lat1 long0 m_e m_a m_1 m_2 m_3 m_4}
+    SphMerc {lat0 long0 m_a}
     CS    {lat0 long0 m_e m_a m_0 m_1 m_2 m_3 m_4 m_5 m_6 m_7 m_8}
     APOLY {lat0 m_a m_0 m_1 m_2 m_3 m_4 m_5 m_6}
     Stereogr   {lat0 long0 k0 m_a m_e m_0 m_1 m_2 m_3}
     Schreiber  {m_0 m_1 m_2 m_3 m_4 m_5}
     SOM   {lat0 long0 k0 m_e m_0 m_1 m_2 m_3 m_4 m_5 m_6}
     EOV   {}
+    EqCyl {lat0 m_a m_0}
 }
 
      # new types here imply changing proc BadParam in check.tcl
@@ -133,16 +138,18 @@ array set MAPPROJDTYPE {
      # projections needing auxiliary parameters computed from the main ones
      #  a specific proc is needed to compute the auxiliary parameters
      #  (see, e.g., proc ProjLCC1ComputeAux)
-set MAPPROJAUX {UTM LCC1 LCC2 Merc1 Merc2 CS APOLY Stereogr Schreiber SOM
-                AEA LEAC}
+set MAPPROJAUX {UTM LCC1 LCC2 Merc1 Merc2 SphMerc CS APOLY Stereogr Schreiber
+		SOM AEA LEAC EqCyl}
      # auxiliary parameters depend on datum?
 array set MAPPROJDEPDATUM {
-    UTM  0      LCC1 1   LCC2  1      Merc1 1    Merc2 1    CS    1   APOLY 1
-    Stereogr 1  SOM  1   Schreiber 0  LambNTF 1  AEA   1    LEAC  1
+    UTM  0   LCC1  1   LCC2     1   Merc1 1   Merc2     1   SphMerc 1  
+    CS   1   APOLY 1   Stereogr 1   SOM   1   Schreiber 0   LambNTF 1
+    AEA  1   LEAC  1   EqCyl    1
 }
 
      # main projections admitting particular cases
-set MAINPROJS {TM LCC1 LCC2 Merc1 Merc2 CS APOLY Stereogr SOM AEA LEAC}
+set MAINPROJS {TM LCC1 LCC2 Merc1 Merc2 SphMerc CS APOLY Stereogr SOM AEA LEAC
+               EqCyl}
 
      # parameters for special cases of Transverse Mercator:
      #  prefix of long0 parameter name, minimum and maximum values for
@@ -231,9 +238,13 @@ array set LNTFzIV {
 }
 
      # particular cases of main projections:
-     #  CMP  - used in Portuguese Military Maps
      #  BNG  - used for the British National Grid
      #  BWI  - used for the British West Indies Grid
+     #  CMP  - used in Portuguese Military Maps
+     #  EOV  - used for the Hungarian National Grid
+     #  EPSG:3857 - used by OpenStreetMap, Nasa landsat, Yahoo, Google Maps...
+     #     also known as EPSG:900913, EPSG:102113
+     #  EPSG:32663 - Plate Carree with WGS 84 datum
      #  IcG  - used for the Iceland Grid
      #  ITM  - used for the Irish TM Grid
      #  KKJY - used for the Uniform Finnish Grid
@@ -248,6 +259,8 @@ array set MAPPARTPROJ {
     BNG  TM
     BWI  TM
     EOV  EOV
+    EPSG:3857 SphMerc
+    EPSG:32663 EqCyl
     IcG  LCC2
     ITM  TM
     KKJY TM
@@ -261,10 +274,12 @@ array set MAPPARTPROJ {
 
      # parameters aligned with MAPPROJDATA above
 array set MAPPARTPDATA {
-    CMP  {39.66666666666667 -8.13190611111111 1}
     BNG  {49.0 -2.0 0.9996012717}
     BWI  {0 -62.0 0.9995}
+    CMP  {39.66666666666667 -8.13190611111111 1}
     EOV  {}
+    EPSG:3857 {0 0}
+    EPSG:32663 {0}
     IcG  {64.75 64.25 65 -19}
     ITM  {53.5 -8.0 1.000035}
     KKJY {0 27.0 1}
@@ -288,6 +303,9 @@ array set GRIDFOR {
     CS   UTM/UPS
     CTR  CTR
     EOV  EOV
+    EPSG:3857 UTM/UPS
+    EPSG:32663 UTM/UPS
+    EqCyl UTM/UPS
     GKK  GKK
     IcG  IcG
     ITM  ITM
@@ -306,6 +324,7 @@ array set GRIDFOR {
     SEG  SEG
     Schreiber RDG
     SOM  UTM/UPS
+    SphMerc UTM/UPS
     Stereogr UTM/UPS
     TAlbers  TAlbers
     TM   UTM/UPS
@@ -391,6 +410,8 @@ foreach g [array names TMPARAM] {
     set TXT([lindex $TMPARAM($g) 0]long0) $TXT(long0)
 }
 
+## grids
+
 foreach g $GRIDS {
     # all grids named as they should appear in TXT
     set TXT($g) $g ; set INVTXT($g) $g
@@ -403,9 +424,11 @@ foreach g $GRIDS {
 }
 
     # all grids with >1 zone with fixed datum must be given here!
-set GRDLambNTF(datum) "NTF (Nouvelle Triangulation de France)"
-
-## grids
+foreach g {BMN BNG ITM LambNTF} \
+        d {"Austrian (MGI)" "Ord Srvy Grt Britn" "Ireland 1965"
+	   "NTF (Nouvelle Triangulation de France)"} {
+    set GRD${g}(datum) $d
+}
 
 proc SetUpNZGrids {} {
     # initialize grids with no zones defined in array GRIDDEF
@@ -1147,7 +1170,7 @@ proc ProjParams {how proj data} {
 	destroy .proj
 	return 0
     }
-    if { $how != "change" && $how != "set" } {
+    if { $how == "define" || $how == "edit" } {
 	set grid 1
 	set oldgr [set ${data}(_grid)]
 	set abbr [set ${data}(_abbr)]
@@ -1262,6 +1285,7 @@ proc ProjParams {how proj data} {
 	grid configure $frs.zg -column 0 -row $n -columnspan 2 -sticky e \
 		-ipadx 10
     } else {
+	# $how in {change, set}
 	set grid 0 ; set oldgr "" ; set selfgrid 0
     }
     frame .proj.fr.frbs -relief flat -borderwidth 0
@@ -1376,14 +1400,15 @@ proc ProjParams {how proj data} {
 		array set $data $l
 	    }
 	    if { $grid } {
-		global GRD$oldgr
-
 		set newgrid same
 		if { $Param(_guse) } {
 		    if { $oldgr != [set ${data}(_grid)] } {
 			set newgrid diff
+			set newdata diff
 		    }
 		} else {
+		    global GRD$oldgr
+
 		    # check parameters for new/self grid
 		    set unit $Param(_gunit)
 		    set ${data}(_grid) $abbr
@@ -1428,21 +1453,21 @@ proc ProjParams {how proj data} {
 			set datum ""
 			set newgrid diff
 		    } else { set datum "" }
-		}
-		if { $newgrid == "diff" } {
-		    set newdata diff
-		} else {
-		    # make sure grid parameters are set
-		    foreach v "fe fn unit xmin xmax ymin ymax \
+		    if { $newgrid == "diff" } {
+			set newdata diff
+		    } else {
+			# make sure grid parameters are set
+			foreach v "fe fn unit xmin xmax ymin ymax \
                                lamin lamax lomin lomax" {
-			set $v [set GRD${oldgr}(_$v)]
+			    set $v [set GRD${oldgr}(_$v)]
+			}
 		    }
+		    set ${data}(_gparams) \
+			[list $abbr $fe $fn $unit \
+			     [list $xmin $xmax $ymin $ymax] \
+			     [list $lamin $lamax $lomin $lomax] \
+			     $datum]
 		}
-		set ${data}(_gparams) \
-		    [list $abbr $fe $fn $unit \
-			 [list $xmin $xmax $ymin $ymax] \
-			 [list $lamin $lamax $lomin $lomax] \
-			 $datum]
 	    }
 	    if { $ProjRes == "new" } {
 		set r 2
