@@ -1,15 +1,16 @@
 #!/bin/sh
 # This is a Tcl/Tk script to be interpreted by wish (Tk8.3 or better): \
-exec wish8.4 "$0" -- "$@"
+exec wish "$0" -- "$@"
 
+# This is the main file of:
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -58,13 +59,18 @@ exec wish8.4 "$0" -- "$@"
 #  - Sandor Laky (laky.sandor_AT_freemail.hu)
 #      Copyright (c) 2008 by Sandor Laky
 #      implementation of the EOV projection
+#  - Rudolf Martin (rudolf.martin_AT_gmx.de)
+#      Copyright (c) 2010 by Rudolf Martin
+#      plug-ins for creating plots of tracks using gnuplot and for
+#      other computations related with tracks
+#
 ##
 #
 ## German language support:
 #      before version 6.0: by Andreas Lange (Andreas.C.Lange_AT_GMX.de)
 #       Copyright (c) 2002 by Andreas Lange
-#      since version 6.0: by Sabine Broda (sbb_AT_ncc.up.pt) Copyright (c) 2009
-#       by Sabine Broda
+#      since version 6.0: by Sabine Broda (sbb_AT_dcc.fc.up.pt)
+#       Copyright (c) 2009 by Sabine Broda
 ##
 #
 ## Italian language support by Alessandro Palmas (alpalmas_AT_tin.it)
@@ -90,7 +96,7 @@ exec wish8.4 "$0" -- "$@"
 ## Russian language support:
 #      until version 6.4:  by Nikolai Kosyakoff (priroda.net_AT_gmail.com)
 #       Copyright (c) 2007 by Nikolai Kosyakoff
-#      since October 2009: by Alexander B. Preobrazhenskiy, (modul@ihome.ru)
+#      since October 2009: by Alexander B. Preobrazhenskiy, (modul_AT_ihome.ru)
 #       Copyright (c) 2009 by Alexander B. Preobrazhenskiy
 ##
 #
@@ -161,7 +167,7 @@ exec wish8.4 "$0" -- "$@"
 #    - Img, written by Jan Nijtmans
 #      now part of the standard Tcl distribution
 #    - gpsmanshp, written by Miguel Filgueiras
-#      http://www.ncc.up.pt/gpsmanshp
+#      http://sourceforge.net/projects/gpsmanshp
 #      and available as a Debian package under the name gpsmanshp
 #    - TclCurl, available as a Debian package under the name tclcurl
 #
@@ -180,14 +186,14 @@ exec wish8.4 "$0" -- "$@"
 ##
 #
 #  File: gpsman.tcl
-#  Last change:  27 December 2009
+#  Last change:  15 September 2011
 #
 
 ############ configuration parameters
 #
-# the first 4 variables below MUST be correctly set for GPSMan to work!
+# the first 5 variables below MUST be correctly set for GPSMan to work!
 #  DEFSPORT (or SERIALPORT in non-Unix systems), SRCDIR,
-#   USERDIR, USEROPTIONS
+#   USERDIR, USEROPTIONS, USERTMPDIR
 
  # NOTE for non-Unix users: use "/" (not "\") in pathnames
 
@@ -213,11 +219,14 @@ switch $tcl_platform(platform) {
 	# default serial/USB port is
 	set DEFSPORT /dev/ttyS0	
 	# path to directory containing user data
-	set USERDIR ~/.gpsman-dir
+	set USERDIR $env(HOME)/.gpsman-dir
 	# name of user preferences file
 	set USEROPTIONS gpsman-options
-	# default print command
-	set PRINTCMD "/usr/bin/lpr"
+	# path to directory for temporary files (cleaned when GPSMan starts)
+	set USERTMPDIR $USERDIR/.tmp
+	# default HTTP address of the HTML version of the user manual
+	#  set to "" if unavailable
+	set DEFTMANHTTPADDR "file:///usr/share/doc/gpsman/html"
     }
     default {
 	set UNIX 0 ; set CMDLINE 0
@@ -229,13 +238,16 @@ switch $tcl_platform(platform) {
 	set USERDIR gpmandir
 	# name of user preferences file
 	set USEROPTIONS gpmanopt
-	# default print command
-	set PRINTCMD ""
+	# path to directory for temporary files (cleaned when GPSMan starts)
+	set USERTMPDIR [file join $USERDIR .tmp]
+	# default HTTP address of the HTML version of the user manual
+	#  set to "" if unavailable
+	set DEFTMANHTTPADDR ""
     }
 }
 
  # path to directory containing program files
-set SRCDIR /usr/lib/gpsman
+set SRCDIR gmsrc
 
 # all other default configuration is now done in file $SRCDIR/config.tcl
 
@@ -276,7 +288,9 @@ if { ! [file exists $USERDIR] } {
 	# pre-5.4 default options file
 	source ~/.gpsman
     }
-}
+} elseif { ! [file writable $USERDIR] } {
+    set UDUnwritable 1
+} else { set UDUnwritable 0 }
 
 if { [file readable $USEROPTIONS] } {
     source $USEROPTIONS
